import React, { Component } from 'react';
import PubSub from 'pubsub-js';
import {  withLeaflet, LayerGroup } from 'react-leaflet';
import MoveableMarker from '../common/MoveableMarker';

/**
 * MoveableObject layer allows to show 
 */
class MoveableObjectLayer extends Component {
	state = {
		markers: [],
	}

	componentDidMount(){
		PubSub.subscribe('map.card.add', (msg, data) => {
			let element = <MoveableMarker 
					data={data} 
					key={data.card_id}
					ref={this.marker}
				></MoveableMarker>
			this.setState({markers: [...this.state.markers, element]});
		});

        PubSub.subscribe('map.card.move', (msg, data) => {
			// eslint-disable-next-line
			let marker = this.state.markers.filter(m => m.key == data.card_id);
			if(marker.length > 0){
				PubSub.publish("map.marker.move", {id: data.card_id, lat: data.lat, lng: data.lng, duration: data.delta_time});
			}
		});

        PubSub.subscribe('map.card.remove', (msg, data) => {
			// eslint-disable-next-line
			let markers = this.state.markers.filter(m => m.key != data.card_id);
			this.setState({markers: markers});
		});
	}

	move(){

	}

	stop(){
		
	}

	componentWillUnmount(){
		PubSub.unsubscribe('map.card.add');
		PubSub.unsubscribe('map.card.move');
		PubSub.unsubscribe('map.card.remove');
	}

	render() {
		return (
			<LayerGroup key="moveable">
				{ this.state.markers }
			</LayerGroup>
		);
	}
}
export default withLeaflet(MoveableObjectLayer);
